import * as pulumi from "@pulumi/pulumi";
/**
 * Retrieves a config item.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as scm from "@pulumi/scm";
 *
 * const example = new scm.AddressObject("example", {
 *     folder: "Shared",
 *     name: "example",
 *     description: "Made by Pulumi",
 *     ipNetmask: "10.2.3.4",
 * });
 * ```
 */
export declare class AddressObject extends pulumi.CustomResource {
    /**
     * Get an existing AddressObject resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: AddressObjectState, opts?: pulumi.CustomResourceOptions): AddressObject;
    /**
     * Returns true if the given object is an instance of AddressObject.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is AddressObject;
    /**
     * The Description param. String length must not exceed 1023 characters.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The Device param.
     */
    readonly device: pulumi.Output<string | undefined>;
    /**
     * The Folder param.
     */
    readonly folder: pulumi.Output<string | undefined>;
    /**
     * The Fqdn param. String length must be between 1 and 255 characters. String validation regex: `^a-zA-Z0-9_+[a-zA-Z0-9]$`. Ensure that only one of the following is specified: `fqdn`, `ipNetmask`, `ipRange`, `ipWildcard`
     */
    readonly fqdn: pulumi.Output<string | undefined>;
    /**
     * The IpNetmask param. Ensure that only one of the following is specified: `fqdn`, `ipNetmask`, `ipRange`, `ipWildcard`
     */
    readonly ipNetmask: pulumi.Output<string | undefined>;
    /**
     * The IpRange param. Ensure that only one of the following is specified: `fqdn`, `ipNetmask`, `ipRange`, `ipWildcard`
     */
    readonly ipRange: pulumi.Output<string | undefined>;
    /**
     * The IpWildcard param. Ensure that only one of the following is specified: `fqdn`, `ipNetmask`, `ipRange`, `ipWildcard`
     */
    readonly ipWildcard: pulumi.Output<string | undefined>;
    /**
     * Alphanumeric string [ 0-9a-zA-Z._-]. String length must not exceed 63 characters.
     */
    readonly name: pulumi.Output<string>;
    /**
     * The Snippet param.
     */
    readonly snippet: pulumi.Output<string | undefined>;
    /**
     * Tags for address object. List must contain at most 64 elements. Individual elements in this list are subject to additional validation. String length must not exceed 127 characters.
     */
    readonly tags: pulumi.Output<string[] | undefined>;
    readonly tfid: pulumi.Output<string>;
    /**
     * The Type param.
     */
    readonly type: pulumi.Output<string>;
    /**
     * Create a AddressObject resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: AddressObjectArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering AddressObject resources.
 */
export interface AddressObjectState {
    /**
     * The Description param. String length must not exceed 1023 characters.
     */
    description?: pulumi.Input<string>;
    /**
     * The Device param.
     */
    device?: pulumi.Input<string>;
    /**
     * The Folder param.
     */
    folder?: pulumi.Input<string>;
    /**
     * The Fqdn param. String length must be between 1 and 255 characters. String validation regex: `^a-zA-Z0-9_+[a-zA-Z0-9]$`. Ensure that only one of the following is specified: `fqdn`, `ipNetmask`, `ipRange`, `ipWildcard`
     */
    fqdn?: pulumi.Input<string>;
    /**
     * The IpNetmask param. Ensure that only one of the following is specified: `fqdn`, `ipNetmask`, `ipRange`, `ipWildcard`
     */
    ipNetmask?: pulumi.Input<string>;
    /**
     * The IpRange param. Ensure that only one of the following is specified: `fqdn`, `ipNetmask`, `ipRange`, `ipWildcard`
     */
    ipRange?: pulumi.Input<string>;
    /**
     * The IpWildcard param. Ensure that only one of the following is specified: `fqdn`, `ipNetmask`, `ipRange`, `ipWildcard`
     */
    ipWildcard?: pulumi.Input<string>;
    /**
     * Alphanumeric string [ 0-9a-zA-Z._-]. String length must not exceed 63 characters.
     */
    name?: pulumi.Input<string>;
    /**
     * The Snippet param.
     */
    snippet?: pulumi.Input<string>;
    /**
     * Tags for address object. List must contain at most 64 elements. Individual elements in this list are subject to additional validation. String length must not exceed 127 characters.
     */
    tags?: pulumi.Input<pulumi.Input<string>[]>;
    tfid?: pulumi.Input<string>;
    /**
     * The Type param.
     */
    type?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a AddressObject resource.
 */
export interface AddressObjectArgs {
    /**
     * The Description param. String length must not exceed 1023 characters.
     */
    description?: pulumi.Input<string>;
    /**
     * The Device param.
     */
    device?: pulumi.Input<string>;
    /**
     * The Folder param.
     */
    folder?: pulumi.Input<string>;
    /**
     * The Fqdn param. String length must be between 1 and 255 characters. String validation regex: `^a-zA-Z0-9_+[a-zA-Z0-9]$`. Ensure that only one of the following is specified: `fqdn`, `ipNetmask`, `ipRange`, `ipWildcard`
     */
    fqdn?: pulumi.Input<string>;
    /**
     * The IpNetmask param. Ensure that only one of the following is specified: `fqdn`, `ipNetmask`, `ipRange`, `ipWildcard`
     */
    ipNetmask?: pulumi.Input<string>;
    /**
     * The IpRange param. Ensure that only one of the following is specified: `fqdn`, `ipNetmask`, `ipRange`, `ipWildcard`
     */
    ipRange?: pulumi.Input<string>;
    /**
     * The IpWildcard param. Ensure that only one of the following is specified: `fqdn`, `ipNetmask`, `ipRange`, `ipWildcard`
     */
    ipWildcard?: pulumi.Input<string>;
    /**
     * Alphanumeric string [ 0-9a-zA-Z._-]. String length must not exceed 63 characters.
     */
    name?: pulumi.Input<string>;
    /**
     * The Snippet param.
     */
    snippet?: pulumi.Input<string>;
    /**
     * Tags for address object. List must contain at most 64 elements. Individual elements in this list are subject to additional validation. String length must not exceed 127 characters.
     */
    tags?: pulumi.Input<pulumi.Input<string>[]>;
}
