import * as pulumi from "@pulumi/pulumi";
import * as inputs from "./types/input";
import * as outputs from "./types/output";
/**
 * Retrieves a config item.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as scm from "@pulumi/scm";
 *
 * const example = new scm.Application("example", {});
 * ```
 */
export declare class Application extends pulumi.CustomResource {
    /**
     * Get an existing Application resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: ApplicationState, opts?: pulumi.CustomResourceOptions): Application;
    /**
     * Returns true if the given object is an instance of Application.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Application;
    /**
     * The AbleToTransferFile param.
     */
    readonly ableToTransferFile: pulumi.Output<boolean | undefined>;
    /**
     * The AlgDisableCapability param. String length must not exceed 127 characters.
     */
    readonly algDisableCapability: pulumi.Output<string | undefined>;
    /**
     * The Category param.
     */
    readonly category: pulumi.Output<string>;
    /**
     * The ConsumeBigBandwidth param.
     */
    readonly consumeBigBandwidth: pulumi.Output<boolean | undefined>;
    /**
     * The DataIdent param.
     */
    readonly dataIdent: pulumi.Output<boolean | undefined>;
    /**
     * The Default param.
     */
    readonly default: pulumi.Output<outputs.ApplicationDefault | undefined>;
    /**
     * The Description param. String length must not exceed 1023 characters.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The Device param.
     */
    readonly device: pulumi.Output<string | undefined>;
    /**
     * The EvasiveBehavior param.
     */
    readonly evasiveBehavior: pulumi.Output<boolean | undefined>;
    /**
     * The FileTypeIdent param.
     */
    readonly fileTypeIdent: pulumi.Output<boolean | undefined>;
    /**
     * The Folder param.
     */
    readonly folder: pulumi.Output<string | undefined>;
    /**
     * The HasKnownVulnerability param.
     */
    readonly hasKnownVulnerability: pulumi.Output<boolean | undefined>;
    /**
     * Alphanumeric string [ 0-9a-zA-Z._-]. String length must not exceed 31 characters.
     */
    readonly name: pulumi.Output<string>;
    /**
     * The NoAppidCaching param.
     */
    readonly noAppidCaching: pulumi.Output<boolean | undefined>;
    /**
     * The ParentApp param. String length must not exceed 127 characters.
     */
    readonly parentApp: pulumi.Output<string | undefined>;
    /**
     * The PervasiveUse param.
     */
    readonly pervasiveUse: pulumi.Output<boolean | undefined>;
    /**
     * The ProneToMisuse param.
     */
    readonly proneToMisuse: pulumi.Output<boolean | undefined>;
    /**
     * The Risk param. Value must be between 1 and 5.
     */
    readonly risk: pulumi.Output<number>;
    /**
     * The Signatures param.
     */
    readonly signatures: pulumi.Output<outputs.ApplicationSignature[] | undefined>;
    /**
     * The Snippet param.
     */
    readonly snippet: pulumi.Output<string | undefined>;
    /**
     * The Subcategory param. String length must not exceed 63 characters.
     */
    readonly subcategory: pulumi.Output<string>;
    /**
     * timeout for half-close session in seconds. Value must be between 1 and 604800.
     */
    readonly tcpHalfClosedTimeout: pulumi.Output<number | undefined>;
    /**
     * timeout for session in timeWait state in seconds. Value must be between 1 and 600.
     */
    readonly tcpTimeWaitTimeout: pulumi.Output<number | undefined>;
    /**
     * timeout in seconds. Value must be between 0 and 604800.
     */
    readonly tcpTimeout: pulumi.Output<number | undefined>;
    /**
     * The Technology param. String length must not exceed 63 characters.
     */
    readonly technology: pulumi.Output<string>;
    readonly tfid: pulumi.Output<string>;
    /**
     * timeout in seconds. Value must be between 0 and 604800.
     */
    readonly timeout: pulumi.Output<number | undefined>;
    /**
     * The TunnelApplications param.
     */
    readonly tunnelApplications: pulumi.Output<boolean | undefined>;
    /**
     * The TunnelOtherApplication param.
     */
    readonly tunnelOtherApplication: pulumi.Output<boolean | undefined>;
    /**
     * timeout in seconds. Value must be between 0 and 604800.
     */
    readonly udpTimeout: pulumi.Output<number | undefined>;
    /**
     * The UsedByMalware param.
     */
    readonly usedByMalware: pulumi.Output<boolean | undefined>;
    /**
     * The VirusIdent param.
     */
    readonly virusIdent: pulumi.Output<boolean | undefined>;
    /**
     * Create a Application resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ApplicationArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering Application resources.
 */
export interface ApplicationState {
    /**
     * The AbleToTransferFile param.
     */
    ableToTransferFile?: pulumi.Input<boolean>;
    /**
     * The AlgDisableCapability param. String length must not exceed 127 characters.
     */
    algDisableCapability?: pulumi.Input<string>;
    /**
     * The Category param.
     */
    category?: pulumi.Input<string>;
    /**
     * The ConsumeBigBandwidth param.
     */
    consumeBigBandwidth?: pulumi.Input<boolean>;
    /**
     * The DataIdent param.
     */
    dataIdent?: pulumi.Input<boolean>;
    /**
     * The Default param.
     */
    default?: pulumi.Input<inputs.ApplicationDefault>;
    /**
     * The Description param. String length must not exceed 1023 characters.
     */
    description?: pulumi.Input<string>;
    /**
     * The Device param.
     */
    device?: pulumi.Input<string>;
    /**
     * The EvasiveBehavior param.
     */
    evasiveBehavior?: pulumi.Input<boolean>;
    /**
     * The FileTypeIdent param.
     */
    fileTypeIdent?: pulumi.Input<boolean>;
    /**
     * The Folder param.
     */
    folder?: pulumi.Input<string>;
    /**
     * The HasKnownVulnerability param.
     */
    hasKnownVulnerability?: pulumi.Input<boolean>;
    /**
     * Alphanumeric string [ 0-9a-zA-Z._-]. String length must not exceed 31 characters.
     */
    name?: pulumi.Input<string>;
    /**
     * The NoAppidCaching param.
     */
    noAppidCaching?: pulumi.Input<boolean>;
    /**
     * The ParentApp param. String length must not exceed 127 characters.
     */
    parentApp?: pulumi.Input<string>;
    /**
     * The PervasiveUse param.
     */
    pervasiveUse?: pulumi.Input<boolean>;
    /**
     * The ProneToMisuse param.
     */
    proneToMisuse?: pulumi.Input<boolean>;
    /**
     * The Risk param. Value must be between 1 and 5.
     */
    risk?: pulumi.Input<number>;
    /**
     * The Signatures param.
     */
    signatures?: pulumi.Input<pulumi.Input<inputs.ApplicationSignature>[]>;
    /**
     * The Snippet param.
     */
    snippet?: pulumi.Input<string>;
    /**
     * The Subcategory param. String length must not exceed 63 characters.
     */
    subcategory?: pulumi.Input<string>;
    /**
     * timeout for half-close session in seconds. Value must be between 1 and 604800.
     */
    tcpHalfClosedTimeout?: pulumi.Input<number>;
    /**
     * timeout for session in timeWait state in seconds. Value must be between 1 and 600.
     */
    tcpTimeWaitTimeout?: pulumi.Input<number>;
    /**
     * timeout in seconds. Value must be between 0 and 604800.
     */
    tcpTimeout?: pulumi.Input<number>;
    /**
     * The Technology param. String length must not exceed 63 characters.
     */
    technology?: pulumi.Input<string>;
    tfid?: pulumi.Input<string>;
    /**
     * timeout in seconds. Value must be between 0 and 604800.
     */
    timeout?: pulumi.Input<number>;
    /**
     * The TunnelApplications param.
     */
    tunnelApplications?: pulumi.Input<boolean>;
    /**
     * The TunnelOtherApplication param.
     */
    tunnelOtherApplication?: pulumi.Input<boolean>;
    /**
     * timeout in seconds. Value must be between 0 and 604800.
     */
    udpTimeout?: pulumi.Input<number>;
    /**
     * The UsedByMalware param.
     */
    usedByMalware?: pulumi.Input<boolean>;
    /**
     * The VirusIdent param.
     */
    virusIdent?: pulumi.Input<boolean>;
}
/**
 * The set of arguments for constructing a Application resource.
 */
export interface ApplicationArgs {
    /**
     * The AbleToTransferFile param.
     */
    ableToTransferFile?: pulumi.Input<boolean>;
    /**
     * The AlgDisableCapability param. String length must not exceed 127 characters.
     */
    algDisableCapability?: pulumi.Input<string>;
    /**
     * The Category param.
     */
    category: pulumi.Input<string>;
    /**
     * The ConsumeBigBandwidth param.
     */
    consumeBigBandwidth?: pulumi.Input<boolean>;
    /**
     * The DataIdent param.
     */
    dataIdent?: pulumi.Input<boolean>;
    /**
     * The Default param.
     */
    default?: pulumi.Input<inputs.ApplicationDefault>;
    /**
     * The Description param. String length must not exceed 1023 characters.
     */
    description?: pulumi.Input<string>;
    /**
     * The Device param.
     */
    device?: pulumi.Input<string>;
    /**
     * The EvasiveBehavior param.
     */
    evasiveBehavior?: pulumi.Input<boolean>;
    /**
     * The FileTypeIdent param.
     */
    fileTypeIdent?: pulumi.Input<boolean>;
    /**
     * The Folder param.
     */
    folder?: pulumi.Input<string>;
    /**
     * The HasKnownVulnerability param.
     */
    hasKnownVulnerability?: pulumi.Input<boolean>;
    /**
     * Alphanumeric string [ 0-9a-zA-Z._-]. String length must not exceed 31 characters.
     */
    name?: pulumi.Input<string>;
    /**
     * The NoAppidCaching param.
     */
    noAppidCaching?: pulumi.Input<boolean>;
    /**
     * The ParentApp param. String length must not exceed 127 characters.
     */
    parentApp?: pulumi.Input<string>;
    /**
     * The PervasiveUse param.
     */
    pervasiveUse?: pulumi.Input<boolean>;
    /**
     * The ProneToMisuse param.
     */
    proneToMisuse?: pulumi.Input<boolean>;
    /**
     * The Risk param. Value must be between 1 and 5.
     */
    risk: pulumi.Input<number>;
    /**
     * The Signatures param.
     */
    signatures?: pulumi.Input<pulumi.Input<inputs.ApplicationSignature>[]>;
    /**
     * The Snippet param.
     */
    snippet?: pulumi.Input<string>;
    /**
     * The Subcategory param. String length must not exceed 63 characters.
     */
    subcategory: pulumi.Input<string>;
    /**
     * timeout for half-close session in seconds. Value must be between 1 and 604800.
     */
    tcpHalfClosedTimeout?: pulumi.Input<number>;
    /**
     * timeout for session in timeWait state in seconds. Value must be between 1 and 600.
     */
    tcpTimeWaitTimeout?: pulumi.Input<number>;
    /**
     * timeout in seconds. Value must be between 0 and 604800.
     */
    tcpTimeout?: pulumi.Input<number>;
    /**
     * The Technology param. String length must not exceed 63 characters.
     */
    technology: pulumi.Input<string>;
    /**
     * timeout in seconds. Value must be between 0 and 604800.
     */
    timeout?: pulumi.Input<number>;
    /**
     * The TunnelApplications param.
     */
    tunnelApplications?: pulumi.Input<boolean>;
    /**
     * The TunnelOtherApplication param.
     */
    tunnelOtherApplication?: pulumi.Input<boolean>;
    /**
     * timeout in seconds. Value must be between 0 and 604800.
     */
    udpTimeout?: pulumi.Input<number>;
    /**
     * The UsedByMalware param.
     */
    usedByMalware?: pulumi.Input<boolean>;
    /**
     * The VirusIdent param.
     */
    virusIdent?: pulumi.Input<boolean>;
}
