import * as pulumi from "@pulumi/pulumi";
/**
 * Retrieves a config item.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as scm from "@pulumi/scm";
 *
 * const example = new scm.AuthenticationPortal("example", {});
 * ```
 */
export declare class AuthenticationPortal extends pulumi.CustomResource {
    /**
     * Get an existing AuthenticationPortal resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: AuthenticationPortalState, opts?: pulumi.CustomResourceOptions): AuthenticationPortal;
    /**
     * Returns true if the given object is an instance of AuthenticationPortal.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is AuthenticationPortal;
    /**
     * The AuthenticationProfile param.
     */
    readonly authenticationProfile: pulumi.Output<string | undefined>;
    /**
     * The CertificateProfile param.
     */
    readonly certificateProfile: pulumi.Output<string | undefined>;
    /**
     * The Device param.
     */
    readonly device: pulumi.Output<string | undefined>;
    /**
     * The Folder param.
     */
    readonly folder: pulumi.Output<string | undefined>;
    /**
     * The GpUdpPort param. Value must be between 1 and 65535.
     */
    readonly gpUdpPort: pulumi.Output<number | undefined>;
    /**
     * The IdleTimer param. Value must be between 1 and 1440.
     */
    readonly idleTimer: pulumi.Output<number | undefined>;
    /**
     * The RedirectHost param.
     */
    readonly redirectHost: pulumi.Output<string | undefined>;
    /**
     * The Snippet param.
     */
    readonly snippet: pulumi.Output<string | undefined>;
    readonly tfid: pulumi.Output<string>;
    /**
     * The Timer param. Value must be between 1 and 1440.
     */
    readonly timer: pulumi.Output<number | undefined>;
    /**
     * The TlsServiceProfile param.
     */
    readonly tlsServiceProfile: pulumi.Output<string | undefined>;
    /**
     * Create a AuthenticationPortal resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: AuthenticationPortalArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering AuthenticationPortal resources.
 */
export interface AuthenticationPortalState {
    /**
     * The AuthenticationProfile param.
     */
    authenticationProfile?: pulumi.Input<string>;
    /**
     * The CertificateProfile param.
     */
    certificateProfile?: pulumi.Input<string>;
    /**
     * The Device param.
     */
    device?: pulumi.Input<string>;
    /**
     * The Folder param.
     */
    folder?: pulumi.Input<string>;
    /**
     * The GpUdpPort param. Value must be between 1 and 65535.
     */
    gpUdpPort?: pulumi.Input<number>;
    /**
     * The IdleTimer param. Value must be between 1 and 1440.
     */
    idleTimer?: pulumi.Input<number>;
    /**
     * The RedirectHost param.
     */
    redirectHost?: pulumi.Input<string>;
    /**
     * The Snippet param.
     */
    snippet?: pulumi.Input<string>;
    tfid?: pulumi.Input<string>;
    /**
     * The Timer param. Value must be between 1 and 1440.
     */
    timer?: pulumi.Input<number>;
    /**
     * The TlsServiceProfile param.
     */
    tlsServiceProfile?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a AuthenticationPortal resource.
 */
export interface AuthenticationPortalArgs {
    /**
     * The AuthenticationProfile param.
     */
    authenticationProfile?: pulumi.Input<string>;
    /**
     * The CertificateProfile param.
     */
    certificateProfile?: pulumi.Input<string>;
    /**
     * The Device param.
     */
    device?: pulumi.Input<string>;
    /**
     * The Folder param.
     */
    folder?: pulumi.Input<string>;
    /**
     * The GpUdpPort param. Value must be between 1 and 65535.
     */
    gpUdpPort?: pulumi.Input<number>;
    /**
     * The IdleTimer param. Value must be between 1 and 1440.
     */
    idleTimer?: pulumi.Input<number>;
    /**
     * The RedirectHost param.
     */
    redirectHost?: pulumi.Input<string>;
    /**
     * The Snippet param.
     */
    snippet?: pulumi.Input<string>;
    /**
     * The Timer param. Value must be between 1 and 1440.
     */
    timer?: pulumi.Input<number>;
    /**
     * The TlsServiceProfile param.
     */
    tlsServiceProfile?: pulumi.Input<string>;
}
