import * as pulumi from "@pulumi/pulumi";
import * as inputs from "./types/input";
import * as outputs from "./types/output";
/**
 * Retrieves a config item.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as scm from "@pulumi/scm";
 *
 * const example = new scm.DecryptionRule("example", {});
 * ```
 */
export declare class DecryptionRule extends pulumi.CustomResource {
    /**
     * Get an existing DecryptionRule resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: DecryptionRuleState, opts?: pulumi.CustomResourceOptions): DecryptionRule;
    /**
     * Returns true if the given object is an instance of DecryptionRule.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is DecryptionRule;
    /**
     * The Action param. String must be one of these: `"decrypt"`, `"no-decrypt"`.
     */
    readonly action: pulumi.Output<string>;
    /**
     * The Categories param.
     */
    readonly categories: pulumi.Output<string[]>;
    /**
     * The Description param.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The DestinationHips param.
     */
    readonly destinationHips: pulumi.Output<string[] | undefined>;
    /**
     * The Destinations param.
     */
    readonly destinations: pulumi.Output<string[]>;
    /**
     * The Device param.
     */
    readonly device: pulumi.Output<string | undefined>;
    /**
     * The Disabled param.
     */
    readonly disabled: pulumi.Output<boolean | undefined>;
    /**
     * The Folder param.
     */
    readonly folder: pulumi.Output<string | undefined>;
    /**
     * The Froms param.
     */
    readonly froms: pulumi.Output<string[]>;
    /**
     * The LogFail param.
     */
    readonly logFail: pulumi.Output<boolean | undefined>;
    /**
     * The LogSetting param.
     */
    readonly logSetting: pulumi.Output<string | undefined>;
    /**
     * The LogSuccess param.
     */
    readonly logSuccess: pulumi.Output<boolean | undefined>;
    /**
     * The Name param.
     */
    readonly name: pulumi.Output<string>;
    /**
     * The NegateDestination param.
     */
    readonly negateDestination: pulumi.Output<boolean | undefined>;
    /**
     * The NegateSource param.
     */
    readonly negateSource: pulumi.Output<boolean | undefined>;
    /**
     * The Position param. String must be one of these: `"pre"`, `"post"`. Default: `"pre"`.
     */
    readonly position: pulumi.Output<string>;
    /**
     * The Profile param.
     */
    readonly profile: pulumi.Output<string | undefined>;
    /**
     * The Services param.
     */
    readonly services: pulumi.Output<string[]>;
    /**
     * The Snippet param.
     */
    readonly snippet: pulumi.Output<string | undefined>;
    /**
     * The SourceHips param.
     */
    readonly sourceHips: pulumi.Output<string[] | undefined>;
    /**
     * The SourceUsers param.
     */
    readonly sourceUsers: pulumi.Output<string[]>;
    /**
     * The Sources param.
     */
    readonly sources: pulumi.Output<string[]>;
    /**
     * The Tags param.
     */
    readonly tags: pulumi.Output<string[] | undefined>;
    readonly tfid: pulumi.Output<string>;
    /**
     * The Tos param.
     */
    readonly tos: pulumi.Output<string[]>;
    /**
     * The Type param.
     */
    readonly type: pulumi.Output<outputs.DecryptionRuleType | undefined>;
    /**
     * Create a DecryptionRule resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: DecryptionRuleArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering DecryptionRule resources.
 */
export interface DecryptionRuleState {
    /**
     * The Action param. String must be one of these: `"decrypt"`, `"no-decrypt"`.
     */
    action?: pulumi.Input<string>;
    /**
     * The Categories param.
     */
    categories?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The Description param.
     */
    description?: pulumi.Input<string>;
    /**
     * The DestinationHips param.
     */
    destinationHips?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The Destinations param.
     */
    destinations?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The Device param.
     */
    device?: pulumi.Input<string>;
    /**
     * The Disabled param.
     */
    disabled?: pulumi.Input<boolean>;
    /**
     * The Folder param.
     */
    folder?: pulumi.Input<string>;
    /**
     * The Froms param.
     */
    froms?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The LogFail param.
     */
    logFail?: pulumi.Input<boolean>;
    /**
     * The LogSetting param.
     */
    logSetting?: pulumi.Input<string>;
    /**
     * The LogSuccess param.
     */
    logSuccess?: pulumi.Input<boolean>;
    /**
     * The Name param.
     */
    name?: pulumi.Input<string>;
    /**
     * The NegateDestination param.
     */
    negateDestination?: pulumi.Input<boolean>;
    /**
     * The NegateSource param.
     */
    negateSource?: pulumi.Input<boolean>;
    /**
     * The Position param. String must be one of these: `"pre"`, `"post"`. Default: `"pre"`.
     */
    position?: pulumi.Input<string>;
    /**
     * The Profile param.
     */
    profile?: pulumi.Input<string>;
    /**
     * The Services param.
     */
    services?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The Snippet param.
     */
    snippet?: pulumi.Input<string>;
    /**
     * The SourceHips param.
     */
    sourceHips?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The SourceUsers param.
     */
    sourceUsers?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The Sources param.
     */
    sources?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The Tags param.
     */
    tags?: pulumi.Input<pulumi.Input<string>[]>;
    tfid?: pulumi.Input<string>;
    /**
     * The Tos param.
     */
    tos?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The Type param.
     */
    type?: pulumi.Input<inputs.DecryptionRuleType>;
}
/**
 * The set of arguments for constructing a DecryptionRule resource.
 */
export interface DecryptionRuleArgs {
    /**
     * The Action param. String must be one of these: `"decrypt"`, `"no-decrypt"`.
     */
    action: pulumi.Input<string>;
    /**
     * The Categories param.
     */
    categories: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The Description param.
     */
    description?: pulumi.Input<string>;
    /**
     * The DestinationHips param.
     */
    destinationHips?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The Destinations param.
     */
    destinations: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The Device param.
     */
    device?: pulumi.Input<string>;
    /**
     * The Disabled param.
     */
    disabled?: pulumi.Input<boolean>;
    /**
     * The Folder param.
     */
    folder?: pulumi.Input<string>;
    /**
     * The Froms param.
     */
    froms: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The LogFail param.
     */
    logFail?: pulumi.Input<boolean>;
    /**
     * The LogSetting param.
     */
    logSetting?: pulumi.Input<string>;
    /**
     * The LogSuccess param.
     */
    logSuccess?: pulumi.Input<boolean>;
    /**
     * The Name param.
     */
    name?: pulumi.Input<string>;
    /**
     * The NegateDestination param.
     */
    negateDestination?: pulumi.Input<boolean>;
    /**
     * The NegateSource param.
     */
    negateSource?: pulumi.Input<boolean>;
    /**
     * The Position param. String must be one of these: `"pre"`, `"post"`. Default: `"pre"`.
     */
    position?: pulumi.Input<string>;
    /**
     * The Profile param.
     */
    profile?: pulumi.Input<string>;
    /**
     * The Services param.
     */
    services: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The Snippet param.
     */
    snippet?: pulumi.Input<string>;
    /**
     * The SourceHips param.
     */
    sourceHips?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The SourceUsers param.
     */
    sourceUsers: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The Sources param.
     */
    sources: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The Tags param.
     */
    tags?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The Tos param.
     */
    tos: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The Type param.
     */
    type?: pulumi.Input<inputs.DecryptionRuleType>;
}
