import * as pulumi from "@pulumi/pulumi";
/**
 * Retrieves a config item.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as scm from "@pulumi/scm";
 *
 * const example = scm.getAddressObject({
 *     id: "1234-56-789",
 * });
 * ```
 */
export declare function getAddressObject(args: GetAddressObjectArgs, opts?: pulumi.InvokeOptions): Promise<GetAddressObjectResult>;
/**
 * A collection of arguments for invoking getAddressObject.
 */
export interface GetAddressObjectArgs {
    /**
     * The Id param.
     */
    id: string;
}
/**
 * A collection of values returned by getAddressObject.
 */
export interface GetAddressObjectResult {
    /**
     * The Description param. String length must not exceed 1023 characters.
     */
    readonly description: string;
    /**
     * The Fqdn param. String length must be between 1 and 255 characters. String validation regex: `^a-zA-Z0-9_+[a-zA-Z0-9]$`.
     */
    readonly fqdn: string;
    /**
     * The Id param.
     */
    readonly id: string;
    /**
     * The IpNetmask param.
     */
    readonly ipNetmask: string;
    /**
     * The IpRange param.
     */
    readonly ipRange: string;
    /**
     * The IpWildcard param.
     */
    readonly ipWildcard: string;
    /**
     * Alphanumeric string [ 0-9a-zA-Z._-]. String length must not exceed 63 characters.
     */
    readonly name: string;
    /**
     * Tags for address object. List must contain at most 64 elements. Individual elements in this list are subject to additional validation. String length must not exceed 127 characters.
     */
    readonly tags: string[];
    readonly tfid: string;
    /**
     * The Type param.
     */
    readonly type: string;
}
/**
 * Retrieves a config item.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as scm from "@pulumi/scm";
 *
 * const example = scm.getAddressObject({
 *     id: "1234-56-789",
 * });
 * ```
 */
export declare function getAddressObjectOutput(args: GetAddressObjectOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetAddressObjectResult>;
/**
 * A collection of arguments for invoking getAddressObject.
 */
export interface GetAddressObjectOutputArgs {
    /**
     * The Id param.
     */
    id: pulumi.Input<string>;
}
