import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * Retrieves a config item.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as scm from "@pulumi/scm";
 *
 * const example = scm.getAntiSpywareSignature({
 *     id: "1234-56-789",
 * });
 * ```
 */
export declare function getAntiSpywareSignature(args: GetAntiSpywareSignatureArgs, opts?: pulumi.InvokeOptions): Promise<GetAntiSpywareSignatureResult>;
/**
 * A collection of arguments for invoking getAntiSpywareSignature.
 */
export interface GetAntiSpywareSignatureArgs {
    /**
     * The Id param.
     */
    id: string;
}
/**
 * A collection of values returned by getAntiSpywareSignature.
 */
export interface GetAntiSpywareSignatureResult {
    /**
     * The Bugtraqs param.
     */
    readonly bugtraqs: string[];
    /**
     * The Comment param. String length must not exceed 256 characters.
     */
    readonly comment: string;
    /**
     * The Cves param.
     */
    readonly cves: string[];
    /**
     * The DefaultAction param.
     */
    readonly defaultAction: outputs.GetAntiSpywareSignatureDefaultAction;
    /**
     * The Direction param. String must be one of these: `"client2server"`, `"server2client"`, `"both"`.
     */
    readonly direction: string;
    /**
     * The Id param.
     */
    readonly id: string;
    /**
     * The References param.
     */
    readonly references: string[];
    /**
     * The Severity param. String must be one of these: `"critical"`, `"low"`, `"high"`, `"medium"`, `"informational"`.
     */
    readonly severity: string;
    /**
     * The Signature param.
     */
    readonly signature: outputs.GetAntiSpywareSignatureSignature;
    readonly tfid: string;
    /**
     * threat id range \n\n and \n\n. Value must be between 15000 and 70000000.
     */
    readonly threatId: number;
    /**
     * The Threatname param. String length must not exceed 1024 characters.
     */
    readonly threatname: string;
    /**
     * The Vendors param.
     */
    readonly vendors: string[];
}
/**
 * Retrieves a config item.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as scm from "@pulumi/scm";
 *
 * const example = scm.getAntiSpywareSignature({
 *     id: "1234-56-789",
 * });
 * ```
 */
export declare function getAntiSpywareSignatureOutput(args: GetAntiSpywareSignatureOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetAntiSpywareSignatureResult>;
/**
 * A collection of arguments for invoking getAntiSpywareSignature.
 */
export interface GetAntiSpywareSignatureOutputArgs {
    /**
     * The Id param.
     */
    id: pulumi.Input<string>;
}
