import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * Retrieves a config item.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as scm from "@pulumi/scm";
 *
 * const example = scm.getApplication({
 *     id: "1234-56-789",
 * });
 * ```
 */
export declare function getApplication(args: GetApplicationArgs, opts?: pulumi.InvokeOptions): Promise<GetApplicationResult>;
/**
 * A collection of arguments for invoking getApplication.
 */
export interface GetApplicationArgs {
    /**
     * The Id param.
     */
    id: string;
}
/**
 * A collection of values returned by getApplication.
 */
export interface GetApplicationResult {
    /**
     * The AbleToTransferFile param.
     */
    readonly ableToTransferFile: boolean;
    /**
     * The AlgDisableCapability param. String length must not exceed 127 characters.
     */
    readonly algDisableCapability: string;
    /**
     * The Category param.
     */
    readonly category: string;
    /**
     * The ConsumeBigBandwidth param.
     */
    readonly consumeBigBandwidth: boolean;
    /**
     * The DataIdent param.
     */
    readonly dataIdent: boolean;
    /**
     * The Default param.
     */
    readonly default: outputs.GetApplicationDefault;
    /**
     * The Description param. String length must not exceed 1023 characters.
     */
    readonly description: string;
    /**
     * The EvasiveBehavior param.
     */
    readonly evasiveBehavior: boolean;
    /**
     * The FileTypeIdent param.
     */
    readonly fileTypeIdent: boolean;
    /**
     * The HasKnownVulnerability param.
     */
    readonly hasKnownVulnerability: boolean;
    /**
     * The Id param.
     */
    readonly id: string;
    /**
     * Alphanumeric string [ 0-9a-zA-Z._-]. String length must not exceed 31 characters.
     */
    readonly name: string;
    /**
     * The NoAppidCaching param.
     */
    readonly noAppidCaching: boolean;
    /**
     * The ParentApp param. String length must not exceed 127 characters.
     */
    readonly parentApp: string;
    /**
     * The PervasiveUse param.
     */
    readonly pervasiveUse: boolean;
    /**
     * The ProneToMisuse param.
     */
    readonly proneToMisuse: boolean;
    /**
     * The Risk param. Value must be between 1 and 5.
     */
    readonly risk: number;
    /**
     * The Signatures param.
     */
    readonly signatures: outputs.GetApplicationSignature[];
    /**
     * The Subcategory param. String length must not exceed 63 characters.
     */
    readonly subcategory: string;
    /**
     * timeout for half-close session in seconds. Value must be between 1 and 604800.
     */
    readonly tcpHalfClosedTimeout: number;
    /**
     * timeout for session in timeWait state in seconds. Value must be between 1 and 600.
     */
    readonly tcpTimeWaitTimeout: number;
    /**
     * timeout in seconds. Value must be between 0 and 604800.
     */
    readonly tcpTimeout: number;
    /**
     * The Technology param. String length must not exceed 63 characters.
     */
    readonly technology: string;
    readonly tfid: string;
    /**
     * timeout in seconds. Value must be between 0 and 604800.
     */
    readonly timeout: number;
    /**
     * The TunnelApplications param.
     */
    readonly tunnelApplications: boolean;
    /**
     * The TunnelOtherApplication param.
     */
    readonly tunnelOtherApplication: boolean;
    /**
     * timeout in seconds. Value must be between 0 and 604800.
     */
    readonly udpTimeout: number;
    /**
     * The UsedByMalware param.
     */
    readonly usedByMalware: boolean;
    /**
     * The VirusIdent param.
     */
    readonly virusIdent: boolean;
}
/**
 * Retrieves a config item.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as scm from "@pulumi/scm";
 *
 * const example = scm.getApplication({
 *     id: "1234-56-789",
 * });
 * ```
 */
export declare function getApplicationOutput(args: GetApplicationOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetApplicationResult>;
/**
 * A collection of arguments for invoking getApplication.
 */
export interface GetApplicationOutputArgs {
    /**
     * The Id param.
     */
    id: pulumi.Input<string>;
}
