import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * Retrieves a config item.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as scm from "@pulumi/scm";
 *
 * const example = scm.getCertificateProfile({
 *     id: "1234-56-789",
 * });
 * ```
 */
export declare function getCertificateProfile(args: GetCertificateProfileArgs, opts?: pulumi.InvokeOptions): Promise<GetCertificateProfileResult>;
/**
 * A collection of arguments for invoking getCertificateProfile.
 */
export interface GetCertificateProfileArgs {
    /**
     * The Id param.
     */
    id: string;
}
/**
 * A collection of values returned by getCertificateProfile.
 */
export interface GetCertificateProfileResult {
    /**
     * The BlockExpiredCert param.
     */
    readonly blockExpiredCert: boolean;
    /**
     * The BlockTimeoutCert param.
     */
    readonly blockTimeoutCert: boolean;
    /**
     * The BlockUnauthenticatedCert param.
     */
    readonly blockUnauthenticatedCert: boolean;
    /**
     * The BlockUnknownCert param.
     */
    readonly blockUnknownCert: boolean;
    /**
     * The CaCertificates param.
     */
    readonly caCertificates: outputs.GetCertificateProfileCaCertificate[];
    /**
     * The CertStatusTimeout param.
     */
    readonly certStatusTimeout: string;
    /**
     * The CrlReceiveTimeout param.
     */
    readonly crlReceiveTimeout: string;
    /**
     * The Domain param.
     */
    readonly domain: string;
    /**
     * The Id param.
     */
    readonly id: string;
    /**
     * Alphanumeric string [ 0-9a-zA-Z._-]. String length must not exceed 63 characters.
     */
    readonly name: string;
    /**
     * The OcspReceiveTimeout param.
     */
    readonly ocspReceiveTimeout: string;
    readonly tfid: string;
    /**
     * The UseCrl param.
     */
    readonly useCrl: boolean;
    /**
     * The UseOcsp param.
     */
    readonly useOcsp: boolean;
    /**
     * The UsernameField param.
     */
    readonly usernameField: outputs.GetCertificateProfileUsernameField;
}
/**
 * Retrieves a config item.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as scm from "@pulumi/scm";
 *
 * const example = scm.getCertificateProfile({
 *     id: "1234-56-789",
 * });
 * ```
 */
export declare function getCertificateProfileOutput(args: GetCertificateProfileOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetCertificateProfileResult>;
/**
 * A collection of arguments for invoking getCertificateProfile.
 */
export interface GetCertificateProfileOutputArgs {
    /**
     * The Id param.
     */
    id: pulumi.Input<string>;
}
