import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * Retrieves a config item.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as scm from "@pulumi/scm";
 *
 * const example = scm.getIkeGateway({
 *     id: "1234-56-789",
 * });
 * ```
 */
export declare function getIkeGateway(args: GetIkeGatewayArgs, opts?: pulumi.InvokeOptions): Promise<GetIkeGatewayResult>;
/**
 * A collection of arguments for invoking getIkeGateway.
 */
export interface GetIkeGatewayArgs {
    /**
     * The Device param.
     */
    device?: string;
    /**
     * The Folder param.
     */
    folder?: string;
    /**
     * The Id param.
     */
    id: string;
    /**
     * The Snippet param.
     */
    snippet?: string;
}
/**
 * A collection of values returned by getIkeGateway.
 */
export interface GetIkeGatewayResult {
    /**
     * The Authentication param.
     */
    readonly authentication: outputs.GetIkeGatewayAuthentication;
    /**
     * The Device param.
     */
    readonly device?: string;
    /**
     * The Folder param.
     */
    readonly folder?: string;
    /**
     * The Id param.
     */
    readonly id: string;
    /**
     * The LocalId param.
     */
    readonly localId: outputs.GetIkeGatewayLocalId;
    /**
     * Alphanumeric string begin with letter: [0-9a-zA-Z._-]. String length must not exceed 63 characters.
     */
    readonly name: string;
    /**
     * The PeerAddress param.
     */
    readonly peerAddress: outputs.GetIkeGatewayPeerAddress;
    /**
     * The PeerId param.
     */
    readonly peerId: outputs.GetIkeGatewayPeerId;
    /**
     * The Protocol param.
     */
    readonly protocol: outputs.GetIkeGatewayProtocol;
    /**
     * The ProtocolCommon param.
     */
    readonly protocolCommon: outputs.GetIkeGatewayProtocolCommon;
    /**
     * The Snippet param.
     */
    readonly snippet?: string;
    readonly tfid: string;
}
/**
 * Retrieves a config item.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as scm from "@pulumi/scm";
 *
 * const example = scm.getIkeGateway({
 *     id: "1234-56-789",
 * });
 * ```
 */
export declare function getIkeGatewayOutput(args: GetIkeGatewayOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetIkeGatewayResult>;
/**
 * A collection of arguments for invoking getIkeGateway.
 */
export interface GetIkeGatewayOutputArgs {
    /**
     * The Device param.
     */
    device?: pulumi.Input<string>;
    /**
     * The Folder param.
     */
    folder?: pulumi.Input<string>;
    /**
     * The Id param.
     */
    id: pulumi.Input<string>;
    /**
     * The Snippet param.
     */
    snippet?: pulumi.Input<string>;
}
