import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * Retrieves a config item.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as scm from "@pulumi/scm";
 *
 * const example = scm.getIpsecCryptoProfile({
 *     id: "1234-56-789",
 * });
 * ```
 */
export declare function getIpsecCryptoProfile(args: GetIpsecCryptoProfileArgs, opts?: pulumi.InvokeOptions): Promise<GetIpsecCryptoProfileResult>;
/**
 * A collection of arguments for invoking getIpsecCryptoProfile.
 */
export interface GetIpsecCryptoProfileArgs {
    /**
     * The Device param.
     */
    device?: string;
    /**
     * The Folder param.
     */
    folder?: string;
    /**
     * The Id param.
     */
    id: string;
    /**
     * The Snippet param.
     */
    snippet?: string;
}
/**
 * A collection of values returned by getIpsecCryptoProfile.
 */
export interface GetIpsecCryptoProfileResult {
    /**
     * The Ah param.
     */
    readonly ah: outputs.GetIpsecCryptoProfileAh;
    /**
     * The Device param.
     */
    readonly device?: string;
    /**
     * phase-2 DH group (PFS DH group). String must be one of these: `"no-pfs"`, `"group1"`, `"group2"`, `"group5"`, `"group14"`, `"group19"`, `"group20"`. Default: `"group2"`.
     */
    readonly dhGroup: string;
    /**
     * The Esp param.
     */
    readonly esp: outputs.GetIpsecCryptoProfileEsp;
    /**
     * The Folder param.
     */
    readonly folder?: string;
    /**
     * The Id param.
     */
    readonly id: string;
    /**
     * The Lifesize param.
     */
    readonly lifesize: outputs.GetIpsecCryptoProfileLifesize;
    /**
     * The Lifetime param.
     */
    readonly lifetime: outputs.GetIpsecCryptoProfileLifetime;
    /**
     * Alphanumeric string begin with letter: [0-9a-zA-Z._-]. String length must not exceed 31 characters.
     */
    readonly name: string;
    /**
     * The Snippet param.
     */
    readonly snippet?: string;
    readonly tfid: string;
}
/**
 * Retrieves a config item.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as scm from "@pulumi/scm";
 *
 * const example = scm.getIpsecCryptoProfile({
 *     id: "1234-56-789",
 * });
 * ```
 */
export declare function getIpsecCryptoProfileOutput(args: GetIpsecCryptoProfileOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetIpsecCryptoProfileResult>;
/**
 * A collection of arguments for invoking getIpsecCryptoProfile.
 */
export interface GetIpsecCryptoProfileOutputArgs {
    /**
     * The Device param.
     */
    device?: pulumi.Input<string>;
    /**
     * The Folder param.
     */
    folder?: pulumi.Input<string>;
    /**
     * The Id param.
     */
    id: pulumi.Input<string>;
    /**
     * The Snippet param.
     */
    snippet?: pulumi.Input<string>;
}
