import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * Retrieves a config item.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as scm from "@pulumi/scm";
 *
 * const example = scm.getLdapServerProfile({
 *     id: "1234-56-789",
 * });
 * ```
 */
export declare function getLdapServerProfile(args: GetLdapServerProfileArgs, opts?: pulumi.InvokeOptions): Promise<GetLdapServerProfileResult>;
/**
 * A collection of arguments for invoking getLdapServerProfile.
 */
export interface GetLdapServerProfileArgs {
    /**
     * The Id param.
     */
    id: string;
}
/**
 * A collection of values returned by getLdapServerProfile.
 */
export interface GetLdapServerProfileResult {
    /**
     * The Base param. String length must not exceed 255 characters.
     */
    readonly base: string;
    /**
     * The BindDn param. String length must not exceed 255 characters.
     */
    readonly bindDn: string;
    /**
     * The BindPassword param. String length must not exceed 121 characters.
     */
    readonly bindPassword: string;
    /**
     * The BindTimelimit param.
     */
    readonly bindTimelimit: string;
    /**
     * The Id param.
     */
    readonly id: string;
    /**
     * The LdapType param. String must be one of these: `"active-directory"`, `"e-directory"`, `"sun"`, `"other"`.
     */
    readonly ldapType: string;
    /**
     * The RetryInterval param.
     */
    readonly retryInterval: number;
    /**
     * The Servers param.
     */
    readonly servers: outputs.GetLdapServerProfileServer[];
    /**
     * The Ssl param.
     */
    readonly ssl: boolean;
    readonly tfid: string;
    /**
     * The Timelimit param.
     */
    readonly timelimit: number;
    /**
     * The VerifyServerCertificate param.
     */
    readonly verifyServerCertificate: boolean;
}
/**
 * Retrieves a config item.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as scm from "@pulumi/scm";
 *
 * const example = scm.getLdapServerProfile({
 *     id: "1234-56-789",
 * });
 * ```
 */
export declare function getLdapServerProfileOutput(args: GetLdapServerProfileOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetLdapServerProfileResult>;
/**
 * A collection of arguments for invoking getLdapServerProfile.
 */
export interface GetLdapServerProfileOutputArgs {
    /**
     * The Id param.
     */
    id: pulumi.Input<string>;
}
