import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * Retrieves a config item.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as scm from "@pulumi/scm";
 *
 * const example = scm.getRemoteNetwork({
 *     id: "1234-56-789",
 * });
 * ```
 */
export declare function getRemoteNetwork(args: GetRemoteNetworkArgs, opts?: pulumi.InvokeOptions): Promise<GetRemoteNetworkResult>;
/**
 * A collection of arguments for invoking getRemoteNetwork.
 */
export interface GetRemoteNetworkArgs {
    /**
     * The Folder param. String can either be a specific string(`"Remote Networks"`) or match this regex: `^[\s0-9a-zA-Z._-]{1,}$`. Default: `"Remote Networks"`.
     */
    folder?: string;
    /**
     * The Id param.
     */
    id: string;
}
/**
 * A collection of values returned by getRemoteNetwork.
 */
export interface GetRemoteNetworkResult {
    /**
     * The EcmpLoadBalancing param. String must be one of these: `"enable"`, `"disable"`. Default: `"disable"`.
     */
    readonly ecmpLoadBalancing: string;
    /**
     * ecmp*tunnels is required when ecmp*load*balancing is enable.
     */
    readonly ecmpTunnels: outputs.GetRemoteNetworkEcmpTunnel[];
    /**
     * The Folder param. String can either be a specific string(`"Remote Networks"`) or match this regex: `^[\s0-9a-zA-Z._-]{1,}$`. Default: `"Remote Networks"`.
     */
    readonly folder: string;
    /**
     * The Id param.
     */
    readonly id: string;
    /**
     * ipsec*tunnel is required when ecmp*load_balancing is disable.
     */
    readonly ipsecTunnel: string;
    /**
     * New customer will only be on aggregate bandwidth licensing. String length must exceed 1 characters. Default: `"FWAAS-AGGREGATE"`.
     */
    readonly licenseType: string;
    /**
     * Alphanumeric string begin with letter: [0-9a-zA-Z._-]. String length must not exceed 63 characters.
     */
    readonly name: string;
    /**
     * setup the protocol when ecmp*load*balancing is disable.
     */
    readonly protocol: outputs.GetRemoteNetworkProtocol;
    /**
     * The Region param. String length must exceed 1 characters.
     */
    readonly region: string;
    /**
     * specify secondary ipsecTunnel if needed.
     */
    readonly secondaryIpsecTunnel: string;
    /**
     * spn-name is needed when licenseType is FWAAS-AGGREGATE.
     */
    readonly spnName: string;
    /**
     * The Subnets param.
     */
    readonly subnets: string[];
    readonly tfid: string;
}
/**
 * Retrieves a config item.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as scm from "@pulumi/scm";
 *
 * const example = scm.getRemoteNetwork({
 *     id: "1234-56-789",
 * });
 * ```
 */
export declare function getRemoteNetworkOutput(args: GetRemoteNetworkOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetRemoteNetworkResult>;
/**
 * A collection of arguments for invoking getRemoteNetwork.
 */
export interface GetRemoteNetworkOutputArgs {
    /**
     * The Folder param. String can either be a specific string(`"Remote Networks"`) or match this regex: `^[\s0-9a-zA-Z._-]{1,}$`. Default: `"Remote Networks"`.
     */
    folder?: pulumi.Input<string>;
    /**
     * The Id param.
     */
    id: pulumi.Input<string>;
}
