import * as pulumi from "@pulumi/pulumi";
/**
 * The provider type for the scm package. By default, resources use package-wide configuration
 * settings, however an explicit `Provider` instance may be created and passed during resource
 * construction to achieve fine-grained programmatic control over provider settings. See the
 * [documentation](https://www.pulumi.com/docs/reference/programming-model/#providers) for more information.
 */
export declare class Provider extends pulumi.ProviderResource {
    /**
     * Returns true if the given object is an instance of Provider.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Provider;
    /**
     * The file path to the JSON file with auth creds for SCM.
     */
    readonly authFile: pulumi.Output<string | undefined>;
    /**
     * The URL to send auth credentials to which will return a JWT. Default:
     * `https://auth.apps.paloaltonetworks.com/auth/v1/oauth2/access_token`. Environment variable: `SCM_AUTH_URL`. JSON config
     * file variable: `authUrl`.
     */
    readonly authUrl: pulumi.Output<string | undefined>;
    /**
     * The client ID for the connection. Environment variable: `SCM_CLIENT_ID`. JSON config file variable: `clientId`.
     */
    readonly clientId: pulumi.Output<string | undefined>;
    /**
     * The client secret for the connection. Environment variable: `SCM_CLIENT_SECRET`. JSON config file variable:
     * `clientSecret`.
     */
    readonly clientSecret: pulumi.Output<string | undefined>;
    /**
     * The hostname of Strata Cloud Manager API. Default: `api.sase.paloaltonetworks.com`. Environment variable: `SCM_HOST`.
     * JSON config file variable: `host`.
     */
    readonly host: pulumi.Output<string | undefined>;
    /**
     * The logging level of the provider and the underlying communication. Default: `quiet`. Environment variable:
     * `SCM_LOGGING`. JSON config file variable: `logging`.
     */
    readonly logging: pulumi.Output<string | undefined>;
    /**
     * The protocol to use for SCM. This should be 'http' or 'https'. Default: `https`. Environment variable: `SCM_PROTOCOL`.
     * JSON config file variable: `protocol`.
     */
    readonly protocol: pulumi.Output<string | undefined>;
    /**
     * The client scope. Environment variable: `SCM_SCOPE`. JSON config file variable: `scope`.
     */
    readonly scope: pulumi.Output<string | undefined>;
    /**
     * Create a Provider resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: ProviderArgs, opts?: pulumi.ResourceOptions);
}
/**
 * The set of arguments for constructing a Provider resource.
 */
export interface ProviderArgs {
    /**
     * The file path to the JSON file with auth creds for SCM.
     */
    authFile?: pulumi.Input<string>;
    /**
     * The URL to send auth credentials to which will return a JWT. Default:
     * `https://auth.apps.paloaltonetworks.com/auth/v1/oauth2/access_token`. Environment variable: `SCM_AUTH_URL`. JSON config
     * file variable: `authUrl`.
     */
    authUrl?: pulumi.Input<string>;
    /**
     * The client ID for the connection. Environment variable: `SCM_CLIENT_ID`. JSON config file variable: `clientId`.
     */
    clientId?: pulumi.Input<string>;
    /**
     * The client secret for the connection. Environment variable: `SCM_CLIENT_SECRET`. JSON config file variable:
     * `clientSecret`.
     */
    clientSecret?: pulumi.Input<string>;
    /**
     * Custom HTTP headers to be sent with all API commands. Environment variable: `SCM_HEADERS`. JSON config file variable:
     * `headers`.
     */
    headers?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
    /**
     * The hostname of Strata Cloud Manager API. Default: `api.sase.paloaltonetworks.com`. Environment variable: `SCM_HOST`.
     * JSON config file variable: `host`.
     */
    host?: pulumi.Input<string>;
    /**
     * The logging level of the provider and the underlying communication. Default: `quiet`. Environment variable:
     * `SCM_LOGGING`. JSON config file variable: `logging`.
     */
    logging?: pulumi.Input<string>;
    /**
     * The port number to use for API commands, if non-standard for the given protocol. Environment variable: `SCM_PORT`. JSON
     * config file variable: `port`.
     */
    port?: pulumi.Input<number>;
    /**
     * The protocol to use for SCM. This should be 'http' or 'https'. Default: `https`. Environment variable: `SCM_PROTOCOL`.
     * JSON config file variable: `protocol`.
     */
    protocol?: pulumi.Input<string>;
    /**
     * The client scope. Environment variable: `SCM_SCOPE`. JSON config file variable: `scope`.
     */
    scope?: pulumi.Input<string>;
}
